Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(615)

Unified Diff: sim/msp430/trace.h

Issue 124383005: GDB 7.6.50 (Closed) Base URL: http://git.chromium.org/native_client/nacl-gdb.git@upstream
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sim/msp430/sim-main.h ('k') | sim/msp430/trace.c » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sim/msp430/trace.h
diff --git a/sim/rl78/trace.h b/sim/msp430/trace.h
similarity index 66%
copy from sim/rl78/trace.h
copy to sim/msp430/trace.h
index 3ac9a7edae3c556e976eda1238dedc367098577f..02a036e59a7151dc7486a84892df8676c8261895 100644
--- a/sim/rl78/trace.h
+++ b/sim/msp430/trace.h
@@ -1,6 +1,6 @@
-/* trace.h --- interface to tracing output for the RX simulator.
+/* trace.h --- interface to tracing output for the MSP430 simulator.
- Copyright (C) 2005, 2007-2012 Free Software Foundation, Inc.
+ Copyright (C) 2005, 2007-2013 Free Software Foundation, Inc.
Contributed by Red Hat, Inc.
This file is part of the GNU simulators.
@@ -18,11 +18,11 @@
You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>. */
-#ifndef SIM_RL78_TRACE_H_
-#define SIM_RL78_TRACE_H_
+#ifndef SIM_MSP430_TRACE_H_
+#define SIM_MSP430_TRACE_H_
-extern void sim_disasm_init (bfd *);
-extern void sim_disasm_one (void);
-extern int sim_get_current_source_location (const char **, const char **, unsigned int *);
+extern void msp430_trace_init (bfd *);
+extern void msp430_trace_one (int pc);
+extern int msp430_get_current_source_location (const char **, const char **, unsigned int *);
#endif
« no previous file with comments | « sim/msp430/sim-main.h ('k') | sim/msp430/trace.c » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698